==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "persone":  				$messaggio = "personer"; break;
case "La settimana dal":  			$messaggio = "Veckan fr&aring;n"; break;
case "Il giorno dal":  				$messaggio = "Dagen fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "è piena":  				$messaggio = "&auml;r fullbokad"; break;
case "è pieno":  				$messaggio = "&auml;r fullbokad"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Det finns</b> fortfarande lediga rum den &ouml;nskade perioden"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", men vissa r&ouml;relser kommer beh&ouml;va g&ouml;ras under perioderna f&ouml;r <div style=\"display: inline; color: blue;\">&ouml;verl&aring;telseregel 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Det finns inga</b> lediga rum den &ouml;nskade perioden"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Reservationen kan g&ouml;ras om den bryts i"; break;
case "parti":  					$messaggio = "delar"; break;
case "Periodo di":  				$messaggio = "Period f&ouml;r"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "Tariffa":  				$messaggio = "Pris"; break;
case "compresi":  				$messaggio = "inklusive"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "fasta extrakostnader"; break;
case "Ricontrolla":  				$messaggio = "Kolla igen"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "con la tariffa":  			$messaggio = "med pris"; break;
case "Inserisci la prenotazione":  		$messaggio = "Infoga reservationen"; break;
case "settimana":  				$messaggio = "vecka"; break;
case "giorno":  				$messaggio = "dag"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Det finns inga perioder i &ouml;verl&aring;telseregel 1 f&ouml;r vilka reservationer f&ouml;r and&auml;ndare kan g&ouml;ras"; break;
case "costo aggiuntivo unico":  		$messaggio = "enkel extrakostnad"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "veckovis extrakostnad"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daglig extrakostnad"; break;
case "nº di settimane da applicare":  		$messaggio = "antal veckor att till&auml;mpa"; break;
case "nº di giorni da applicare":  		$messaggio = "antal dagar att till&auml;mpa"; break;
case "di costi aggiuntivi":  			$messaggio = "extrakostnader"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "da moltiplicare per":  			$messaggio = "multipliceras med"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Det var inte m&ouml;jligt att till&auml;mpa en eller flera kostader till priset"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj veckorna som extrakostnaden ska till&auml;mpas f&ouml;r"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Indikerande tillg&auml;nglighets&ouml;versikt"; break;
case "potrebbe non essere preciso":  		$messaggio = "kanske inte &auml;r helt korrekt"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "med valda extrakostnader"; break;
case "per":  					$messaggio = "for"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "persona":  				$messaggio = "person"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.8-1.tar.gz: sv/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "persone":  				$messaggio = "personer"; break;
case "La settimana dal":  			$messaggio = "Veckan fr&aring;n"; break;
case "Il giorno dal":  				$messaggio = "Dagen fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "è piena":  				$messaggio = "&auml;r fullbokad"; break;
case "è pieno":  				$messaggio = "&auml;r fullbokad"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":	$messaggio = "<b>Det finns</b> fortfarande lediga rum den &ouml;nskade perioden"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", men vissa r&ouml;relser kommer beh&ouml;va g&ouml;ras under perioderna f&ouml;r <div style=\"display: inline; color: blue;\">&ouml;verl&aring;telseregel 1</div>"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":	$messaggio = "<b>Det finns inga</b> lediga rum den &ouml;nskade perioden"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "Reservationen kan g&ouml;ras om den bryts i"; break;
case "parti":  					$messaggio = "delar"; break;
case "Periodo di":  				$messaggio = "Period f&ouml;r"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "Tariffa":  				$messaggio = "Pris"; break;
case "compresi":  				$messaggio = "inklusive"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "fasta extrakostnader"; break;
case "Ricontrolla":  				$messaggio = "Kolla igen"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "con la tariffa":  			$messaggio = "med pris"; break;
case "Inserisci la prenotazione":  		$messaggio = "Infoga reservationen"; break;
case "settimana":  				$messaggio = "vecka"; break;
case "giorno":  				$messaggio = "dag"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Det finns inga perioder i &ouml;verl&aring;telseregel 1 f&ouml;r vilka reservationer f&ouml;r and&auml;ndare kan g&ouml;ras"; break;
case "costo aggiuntivo unico":  		$messaggio = "enkel extrakostnad"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "veckovis extrakostnad"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daglig extrakostnad"; break;
case "nº di settimane da applicare":  		$messaggio = "antal veckor att till&auml;mpa"; break;
case "nº di giorni da applicare":  		$messaggio = "antal dagar att till&auml;mpa"; break;
case "di costi aggiuntivi":  			$messaggio = "extrakostnader"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "da moltiplicare per":  			$messaggio = "multipliceras med"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":	$messaggio = "Det var inte m&ouml;jligt att till&auml;mpa en eller flera kostader till priset"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj veckorna som extrakostnaden ska till&auml;mpas f&ouml;r"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Indikerande tillg&auml;nglighets&ouml;versikt"; break;
case "potrebbe non essere preciso":  		$messaggio = "kanske inte &auml;r helt korrekt"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "med valda extrakostnader"; break;
case "per":  					$messaggio = "for"; break;
case "Disponibilità":  				$messaggio = "Availability"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "persona":  				$messaggio = "person"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "non disponibile":  			$messaggio = "not available"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
